@@ -226,6 +226,14 @@ namespace xt
                        std::size_t pool_size = 1,
                        layout_type chunk_memory_layout = XTENSOR_DEFAULT_LAYOUT);
 
+    template <class T, class IOH, layout_type L = XTENSOR_DEFAULT_LAYOUT, class IP = xindex_path, class EXT = empty_extension, class S>
+    xchunked_array<xchunk_store_manager<xfile_array<T, IOH, L>, IP>, EXT>
+    chunked_file_array(std::initializer_list<S> shape,
+                       std::initializer_list<S> chunk_shape,
+                       const std::string& path,
+                       std::size_t pool_size = 1,
+                       layout_type chunk_memory_layout = XTENSOR_DEFAULT_LAYOUT);
+
     /**
      * Creates a chunked file array.
      * This function returns an uninitialized ``xchunked_array<xchunk_store_manager<xfile_array<T, IOH>>>``.
@@ -254,6 +262,15 @@ namespace xt
                        std::size_t pool_size = 1,
                        layout_type chunk_memory_layout = XTENSOR_DEFAULT_LAYOUT);
 
+    template <class T, class IOH, layout_type L = XTENSOR_DEFAULT_LAYOUT, class IP = xindex_path, class EXT = empty_extension, class S>
+    xchunked_array<xchunk_store_manager<xfile_array<T, IOH, L>, IP>, EXT>
+    chunked_file_array(std::initializer_list<S> shape,
+                       std::initializer_list<S> chunk_shape,
+                       const std::string& path,
+                       const T& init_value,
+                       std::size_t pool_size = 1,
+                       layout_type chunk_memory_layout = XTENSOR_DEFAULT_LAYOUT);
+
     /**
      * Creates a chunked file array.
      * This function returns a ``xchunked_array<xchunk_store_manager<xfile_array<T, IOH>>>`` initialized from an expression.
@@ -367,13 +384,33 @@ namespace xt
 
     template <class T, class IOH, layout_type L, class IP, class EXT, class S>
     inline xchunked_array<xchunk_store_manager<xfile_array<T, IOH, L>, IP>, EXT>
-    chunked_file_array(S&& shape, S&& chunk_shape, const std::string& path,  const T& init_value,std::size_t pool_size, layout_type chunk_memory_layout)
+    chunked_file_array(std::initializer_list<S> shape, std::initializer_list<S> chunk_shape, const std::string& path, std::size_t pool_size, layout_type chunk_memory_layout)
+    {
+        using sh_type = std::vector<std::size_t>;
+        auto sh = xtl::forward_sequence<sh_type, std::initializer_list<S>>(shape);
+        auto ch_sh = xtl::forward_sequence<sh_type, std::initializer_list<S>>(chunk_shape);
+        return chunked_file_array<T, IOH, L, IP, EXT, sh_type>(std::move(sh), std::move(ch_sh), path, pool_size, chunk_memory_layout);
+    }
+
+    template <class T, class IOH, layout_type L, class IP, class EXT, class S>
+    inline xchunked_array<xchunk_store_manager<xfile_array<T, IOH, L>, IP>, EXT>
+    chunked_file_array(S&& shape, S&& chunk_shape, const std::string& path, const T& init_value, std::size_t pool_size, layout_type chunk_memory_layout)
     {
         using chunk_storage = xchunk_store_manager<xfile_array<T, IOH, L>, IP>;
         chunk_storage chunks(shape, chunk_shape, path, pool_size, init_value, chunk_memory_layout);
         return xchunked_array<chunk_storage, EXT>(std::move(chunks), std::forward<S>(shape), std::forward<S>(chunk_shape));
     }
 
+    template <class T, class IOH, layout_type L, class IP, class EXT, class S>
+    inline xchunked_array<xchunk_store_manager<xfile_array<T, IOH, L>, IP>, EXT>
+    chunked_file_array(std::initializer_list<S> shape, std::initializer_list<S> chunk_shape, const std::string& path,  const T& init_value, std::size_t pool_size, layout_type chunk_memory_layout)
+    {
+        using sh_type = std::vector<std::size_t>;
+        auto sh = xtl::forward_sequence<sh_type, std::initializer_list<S>>(shape);
+        auto ch_sh = xtl::forward_sequence<sh_type, std::initializer_list<S>>(chunk_shape);
+        return chunked_file_array<T, IOH, L, IP, EXT, sh_type>(std::move(sh), std::move(ch_sh), path, init_value, pool_size, chunk_memory_layout);
+    }
+
     template <class IOH, layout_type L, class IP, class EXT, class E, class S>
     inline xchunked_array<xchunk_store_manager<xfile_array<typename E::value_type, IOH, L>, IP>, EXT>
     chunked_file_array(const xexpression<E>& e, S&& chunk_shape, const std::string& path, std::size_t pool_size, layout_type chunk_memory_layout)
